searchNodes=[{"ref":"Tzdata.html","title":"Tzdata","type":"module","doc":"The Tzdata module provides data from the IANA tz database. Also known as the Olson/Eggert database, zoneinfo, tzdata and other names. A list of time zone names (e.g. America/Los_Angeles) are provided. As well as functions for finding out the UTC offset, abbreviation, standard offset (DST) for a specific point in time in a certain timezone."},{"ref":"Tzdata.html#canonical_zone?/1","title":"Tzdata.canonical_zone?/1","type":"function","doc":"Takes the name of a zone. Returns true if zone exists and is canonical. Otherwise false. iex&gt; Tzdata.canonical_zone? &quot;Europe/London&quot; true iex&gt; Tzdata.canonical_zone? &quot;Europe/Jersey&quot; false"},{"ref":"Tzdata.html#canonical_zone_list/0","title":"Tzdata.canonical_zone_list/0","type":"function","doc":"Like zone_list, but excludes aliases for zones."},{"ref":"Tzdata.html#leap_second_data_valid_until/0","title":"Tzdata.leap_second_data_valid_until/0","type":"function","doc":"The time when the leap second information returned from the other leap second related function expires. The date-time is in UTC. Example Tzdata.leap_second_data_valid_until {{2015, 12, 28}, {0, 0, 0}}"},{"ref":"Tzdata.html#leap_seconds/0","title":"Tzdata.leap_seconds/0","type":"function","doc":"Get a list of known leap seconds. The leap seconds are datetime tuples representing the extra leap second to be inserted. The date-times are in UTC. See also leap_seconds_with_tai_diff/1 Example iex&gt; Tzdata.leap_seconds |&gt; Enum.take(2) [{{1972, 6, 30}, {23, 59, 60}}, {{1972, 12, 31}, {23, 59, 60}}]"},{"ref":"Tzdata.html#leap_seconds_with_tai_diff/0","title":"Tzdata.leap_seconds_with_tai_diff/0","type":"function","doc":"Get a list of maps with known leap seconds and the difference between UTC and the TAI in seconds. See also leap_seconds/1 Example iex&gt; Tzdata.leap_seconds_with_tai_diff |&gt; Enum.take(2) [%{date_time: {{1972, 6, 30}, {23, 59, 60}}, tai_diff: 11}, %{date_time: {{1972, 12, 31}, {23, 59, 60}}, tai_diff: 12}]"},{"ref":"Tzdata.html#links/0","title":"Tzdata.links/0","type":"function","doc":"Returns a map of links. Also known as aliases. iex&gt; Tzdata.links[&quot;Europe/Jersey&quot;] &quot;Europe/London&quot;"},{"ref":"Tzdata.html#periods/1","title":"Tzdata.periods/1","type":"function","doc":"Returns a list of periods for the zone_name provided as an argument. A period in this case is a period of time where the UTC offset and standard offset are in a certain way. When they change, for instance in spring when DST takes effect, a new period starts. For instance a period can begin in spring when winter time ends and summer time begins. The period lasts until DST ends. If either the UTC or standard offset change for any reason, a new period begins. For instance instead of DST ending or beginning, a rule change that changes the UTC offset will also mean a new period. The result is tagged with :ok if the zone_name is correct. The from and until times can be :mix, :max or gregorian seconds. Example iex&gt; Tzdata.periods(&quot;Europe/Madrid&quot;) |&gt; elem(1) |&gt; Enum.take(1) [%{from: %{standard: :min, utc: :min, wall: :min}, std_off: 0, until: %{standard: 59989763760, utc: 59989764644, wall: 59989763760}, utc_off: -884, zone_abbr: &quot;LMT&quot;}] iex&gt; Tzdata.periods(&quot;Not existing&quot;) {:error, :not_found}"},{"ref":"Tzdata.html#periods_for_time/3","title":"Tzdata.periods_for_time/3","type":"function","doc":"Get the periods that cover a certain point in time. Usually it will be a list with just one period. But in some cases it will be zero or two periods. For instance when going from summer to winter time (DST to standard time) there will be an overlap if time_type is :wall. zone_name should be a valid time zone name. The function zone_list/0 provides a valid list of valid zone names. time_point is the point in time in gregorian seconds (see erlang calendar module documentation for more info on gregorian seconds). Valid values for time_type is :utc, :wall or :standard. Examples # 63555753600 seconds is equivalent to {{2015, 1, 1}, {0, 0, 0}} iex&gt; Tzdata.periods_for_time(&quot;Asia/Tokyo&quot;, 63587289600, :wall) [%{from: %{standard: 61589289600, utc: 61589257200, wall: 61589289600}, std_off: 0, until: %{standard: :max, utc: :max, wall: :max}, utc_off: 32400, zone_abbr: &quot;JST&quot;}] # 63612960000 seconds is equivalent to 2015-10-25 02:40:00 and is an ambiguous # wall time for the zone. So two possible periods will be returned. iex&gt; Tzdata.periods_for_time(&quot;Europe/Copenhagen&quot;, 63612960000, :wall) [%{from: %{standard: 63594813600, utc: 63594810000, wall: 63594817200}, std_off: 3600, until: %{standard: 63612957600, utc: 63612954000, wall: 63612961200}, utc_off: 3600, zone_abbr: &quot;CEST&quot;}, %{from: %{standard: 63612957600, utc: 63612954000, wall: 63612957600}, std_off: 0, until: %{standard: 63626263200, utc: 63626259600, wall: 63626263200}, utc_off: 3600, zone_abbr: &quot;CET&quot;}] # 63594816000 seconds is equivalent to 2015-03-29 02:40:00 and is a # non-existing wall time for the zone. It is spring and the clock skips that hour. iex&gt; Tzdata.periods_for_time(&quot;Europe/Copenhagen&quot;, 63594816000, :wall) []"},{"ref":"Tzdata.html#tzdata_version/0","title":"Tzdata.tzdata_version/0","type":"function","doc":"Returns tzdata release version as a string. Example: Tzdata.tzdata_version &quot;2014i&quot;"},{"ref":"Tzdata.html#zone_alias?/1","title":"Tzdata.zone_alias?/1","type":"function","doc":"Takes the name of a zone. Returns true if zone exists and is an alias. Otherwise false. iex&gt; Tzdata.zone_alias? &quot;Europe/Jersey&quot; true iex&gt; Tzdata.zone_alias? &quot;Europe/London&quot; false"},{"ref":"Tzdata.html#zone_alias_list/0","title":"Tzdata.zone_alias_list/0","type":"function","doc":"A list of aliases for zone names. For instance Europe/Jersey is an alias for Europe/London. Aliases are also known as linked zones."},{"ref":"Tzdata.html#zone_exists?/1","title":"Tzdata.zone_exists?/1","type":"function","doc":"Takes the name of a zone. Returns true if zone exists. Otherwise false. iex&gt; Tzdata.zone_exists? &quot;Pacific/Auckland&quot; true iex&gt; Tzdata.zone_exists? &quot;America/Sao_Paulo&quot; true iex&gt; Tzdata.zone_exists? &quot;Europe/Jersey&quot; true"},{"ref":"Tzdata.html#zone_list/0","title":"Tzdata.zone_list/0","type":"function","doc":"zone_list provides a list of all the zone names that can be used with DateTime. This includes aliases."},{"ref":"Tzdata.html#zone_lists_grouped/0","title":"Tzdata.zone_lists_grouped/0","type":"function","doc":"Returns a map with keys being group names and the values lists of time zone names. The group names mirror the file names used by the tzinfo database."},{"ref":"Tzdata.html#t:gregorian_seconds/0","title":"Tzdata.gregorian_seconds/0","type":"type","doc":""},{"ref":"Tzdata.html#t:time_zone_period/0","title":"Tzdata.time_zone_period/0","type":"type","doc":""},{"ref":"Tzdata.html#t:time_zone_period_limit/0","title":"Tzdata.time_zone_period_limit/0","type":"type","doc":""},{"ref":"Tzdata.TimeZoneDatabase.html","title":"Tzdata.TimeZoneDatabase","type":"module","doc":"Module for interfacing with the standard library time zone related functions of Elixir 1.8+. Implements the Calendar.TimeZoneDatabase behaviour."},{"ref":"readme.html","title":"Tzdata","type":"extras","doc":"Tzdata Tzdata. The timezone database in Elixir. Extracted from the Calendar library. As of version 1.0.0 the tz release 2019a is included in the package. When a new release is out, it will be automatically downloaded at runtime. The tz release version in use can be verified with the following function: iex&gt; Tzdata.tzdata_version &quot;2019a&quot;"},{"ref":"readme.html#getting-started","title":"Tzdata - Getting started","type":"extras","doc":"To use the Tzdata library with Elixir 1.8, add it to the dependencies in your mix file: defp deps do [ {:tzdata, &quot;~&gt; 1.0.1&quot;}, ] end In your application you can choose to globally configure Elixir to use Tzdata. This can be done by putting the following line in the config file of your application: config :elixir, :time_zone_database, Tzdata.TimeZoneDatabase That&#39;s it! That allows you to use the Elixir standard library to use Tzdata to do time zone calculations. One example is getting the current time in a certain time zone: iex&gt; DateTime.now(&quot;Europe/Copenhagen&quot;) {:ok, #DateTime&lt;2018-11-30 20:51:59.076524+01:00 CET Europe/Copenhagen&gt;} If you do not want Elixir to have a time zone database globally defined you can instead pass the module name Tzdata.TimeZoneDatabase directly to the functions that need a time zone database: DateTime.now(&quot;Europe/Copenhagen&quot;, Tzdata.TimeZoneDatabase)"},{"ref":"readme.html#data-directory-and-releases","title":"Tzdata - Data directory and releases","type":"extras","doc":"The library uses a file directory to store data. By default this directory is priv. In some cases you might want to use a different directory. For instance when using releases this is recommended. If so, create the directory and make sure Elixir can read and write to it. Then use elixir config files like this to tell Tzdata to use that directory: config :tzdata, :data_dir, &quot;/etc/elixir_tzdata_data&quot; Add the release_ets directory from priv to that directory containing the 20xxx.ets file that ships with this library. For instance with this config: config :tzdata, :data_dir, &quot;/etc/elixir_tzdata_data&quot; an .ets file such as /etc/elixir_tzdata_data/release_ets/2017b.ets should be present."},{"ref":"readme.html#automatic-data-updates","title":"Tzdata - Automatic data updates","type":"extras","doc":"By default Tzdata will poll for timezone database updates every day. In case new data is available, Tzdata will download it and use it. This feature can be disabled with the following configuration: config :tzdata, :autoupdate, :disabled If the autoupdate setting is set to disabled, one has to manually put updated .ets files in the release_ets sub-dir of the &quot;data_dir&quot; (see the &quot;Data directory and releases&quot; section above). When IANA releases new versions of the time zone data, this Tzdata library can be used to generate a new .ets file containing the new data."},{"ref":"readme.html#changes-from-0-1-x-to-0-5-x","title":"Tzdata - Changes from 0.1.x to 0.5.x","type":"extras","doc":"The 0.5.1+ versions uses ETS tables and automatically polls the IANA servers for updated data. When a new version of the timezone database is available, it is automatically downloaded and used. For use with Calendar you can still specify tzdata ~&gt; 0.1.7 in your mix.exs file in case you experience problems using version ~&gt; 0.5.20"},{"ref":"readme.html#hackney-dependency-and-security","title":"Tzdata - Hackney dependency and security","type":"extras","doc":"Tzdata depends on Hackney in order to do HTTPS requests to get new updates. This is done because Erlang&#39;s built in HTTP client httpc does not verify SSL certificates when doing HTTPS requests. Hackney verifies the certificate of IANA when getting new tzdata releases from IANA."},{"ref":"readme.html#documentation","title":"Tzdata - Documentation","type":"extras","doc":"Documentation can be found at http://hexdocs.pm/tzdata/"},{"ref":"readme.html#when-new-timezone-data-is-released","title":"Tzdata - When new timezone data is released","type":"extras","doc":"IANA releases new versions of the timezone database frequently. For users of Tzdata version 0.5.x+ the new database will automatically be downloaded, parsed, saved and used in place of the old data."},{"ref":"readme.html#license","title":"Tzdata - License","type":"extras","doc":"The tzdata Elixir library is released under the MIT license. See the LICENSE file. The tz database files (found in the source_data directory of early versions) is public domain."}]